==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebForOfStateDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfStateDetailDescription } from "./WebForOfStateDetailDescription";
/**
 * @hidden
 */
export let WebForOfStateDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfStateDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfStateDetailDescriptionMetadata.a == null) {
                WebForOfStateDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfStateDetailDescriptionMetadata.c(WebForOfStateDetailDescriptionMetadata.a);
            }
            if (a.k(WebForOfStateDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebForOfStateDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ForOfStateDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("StartIndex", "Number:double");
            a.item("ChunkSize", "Number:double");
        }
        static d(a) {
            WebForOfStateDetailDescriptionMetadata.b(a);
            a.ad("WebForOfStateDetail", () => new WebForOfStateDetailDescription());
            a.ac("WebForOfStateDetail", WebForOfStateDetailDescriptionMetadata.a);
        }
    }
    WebForOfStateDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebForOfStateDetailDescriptionMetadata, 'WebForOfStateDetailDescriptionMetadata');
    WebForOfStateDetailDescriptionMetadata.a = null;
    return WebForOfStateDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebForOfStateDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfStateDetailDescription } from "./WebForOfStateDetailDescription";
/**
 * @hidden
 */
export let WebForOfStateDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebForOfStateDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebForOfStateDetailDescriptionMetadata.a == null) {
                WebForOfStateDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebForOfStateDetailDescriptionMetadata.c(WebForOfStateDetailDescriptionMetadata.a);
            }
            if (a.k(WebForOfStateDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebForOfStateDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ForOfStateDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("StartIndex", "Number:double");
            a.item("ChunkSize", "Number:double");
        }
        static d(a) {
            WebForOfStateDetailDescriptionMetadata.b(a);
            a.ae("WebForOfStateDetail", () => new WebForOfStateDetailDescription());
            a.ad("WebForOfStateDetail", WebForOfStateDetailDescriptionMetadata.a);
        }
    }
    WebForOfStateDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebForOfStateDetailDescriptionMetadata, 'WebForOfStateDetailDescriptionMetadata');
    WebForOfStateDetailDescriptionMetadata.a = null;
    return WebForOfStateDetailDescriptionMetadata;
})();
